import{a as i}from"./chunk-T4KNOXOM.js";import{a as s}from"./chunk-23OFDAHQ.js";import"./chunk-64RAZIDH.js";import"./chunk-BKUW36BS.js";import"./chunk-4R6AKNXZ.js";import"./chunk-7BXJKEEM.js";import"./chunk-KKCTMRNV.js";import"./chunk-3JAGLS23.js";import"./chunk-PVZRSI6V.js";import"./chunk-JDVLQXMK.js";import"./chunk-WQ47ED54.js";import"./chunk-AP7GPLJ7.js";import"./chunk-W7QF4GTN.js";import"./chunk-42NANJO2.js";import"./chunk-GYOZBIN2.js";import"./chunk-RLKBNOCG.js";import"./chunk-CR6SF2HR.js";import"./chunk-7AJGXJKH.js";import{O as n}from"./chunk-E5GXGYZM.js";import{b as a}from"./chunk-ZZZJFKF2.js";import{a as r}from"./chunk-YUSHYV7C.js";import"./chunk-C6Q5SG76.js";var g={parse:r(async e=>{let t=await s("info",e);a.debug(t)},"parse")},m={version:"11.16.0"},v=r(()=>m.version,"getVersion"),d={getVersion:v},f=r((e,t,p)=>{a.debug(`rendering info diagram
`+e);let o=i(t);n(o,100,400,!0),o.append("g").append("text").attr("x",100).attr("y",40).attr("class","version").attr("font-size",32).style("text-anchor","middle").text(`v${p}`)},"draw"),c={draw:f},w={parser:g,db:d,renderer:c};export{w as diagram};
