import{l as n,x as o}from"./chunk-LH5Z5GGI.js";var a=class e{_open=o(!1);_projectId=o(null);isOpen=this._open.asReadonly();targetProjectId=this._projectId.asReadonly();open(t){this._projectId.set(t??null),this._open.set(!0)}close(){this._open.set(!1)}static \u0275fac=function(r){return new(r||e)};static \u0275prov=n({token:e,factory:e.\u0275fac,providedIn:"root"})};export{a};
