import{h as o}from"./chunk-ZZZJFKF2.js";import{a as m}from"./chunk-YUSHYV7C.js";var g=m((t,e)=>{let n;return e==="sandbox"&&(n=o("#i"+t)),(e==="sandbox"?o(n.nodes()[0].contentDocument.body):o("body")).select(`[id="${t}"]`)},"getDiagramElement");export{g as a};
