import{B as a,F as s,Ja as n,K as c,o}from"./chunk-LH5Z5GGI.js";var r=class e{appAutofocus=n(!0,{transform:t=>t!==!1});constructor(){let t=o(a).nativeElement;s(()=>{this.appAutofocus()&&t.focus()})}static \u0275fac=function(u){return new(u||e)};static \u0275dir=c({type:e,selectors:[["","appAutofocus",""]],inputs:{appAutofocus:[1,"appAutofocus"]}})};export{r as a};
