import{_ as s}from"./chunk-E5GXGYZM.js";import{h as e}from"./chunk-ZZZJFKF2.js";import{a as n}from"./chunk-YUSHYV7C.js";var a=n(t=>{let{securityLevel:c}=s(),o=e("body");if(c==="sandbox"){let m=e(`#i${t}`).node()?.contentDocument??document;o=e(m.body)}return o.select(`#${t}`)},"selectSvgElement");export{a};
