import{d as u}from"./chunk-C6Q5SG76.js";var E=u(p=>{"use strict";Object.defineProperty(p,"__esModule",{value:!0})});var f=u(O=>{"use strict";Object.defineProperty(O,"__esModule",{value:!0})});var M=u(P=>{"use strict";Object.defineProperty(P,"__esModule",{value:!0})});var y=u(D=>{"use strict";Object.defineProperty(D,"__esModule",{value:!0})});var g=u(C=>{"use strict";Object.defineProperty(C,"__esModule",{value:!0})});var v=u(I=>{"use strict";Object.defineProperty(I,"__esModule",{value:!0})});var A=u(a=>{"use strict";Object.defineProperty(a,"__esModule",{value:!0});a.GenerationJobState=void 0;var L=(function(e){return e.CREATED="CREATED",e.QUEUED="QUEUED",e.ARCHITECTING="ARCHITECTING",e.SPEC_VALIDATED="SPEC_VALIDATED",e.SCAFFOLDING="SCAFFOLDING",e.CODING="CODING",e.COMPILING="COMPILING",e.SECURITY_AUDIT="SECURITY_AUDIT",e.MATERIALIZING="MATERIALIZING",e.READY="READY",e.DEPLOYING="DEPLOYING",e.DEPLOYED="DEPLOYED",e.NEEDS_REVIEW="NEEDS_REVIEW",e.FAILED="FAILED",e.CANCELLED="CANCELLED",e})(L||(a.GenerationJobState=L={}))});var b=u(S=>{"use strict";Object.defineProperty(S,"__esModule",{value:!0})});var T=u(j=>{"use strict";Object.defineProperty(j,"__esModule",{value:!0})});var m=u(N=>{"use strict";Object.defineProperty(N,"__esModule",{value:!0})});var R=u(q=>{"use strict";Object.defineProperty(q,"__esModule",{value:!0})});var B=u(U=>{"use strict";Object.defineProperty(U,"__esModule",{value:!0})});var Y=u(h=>{"use strict";Object.defineProperty(h,"__esModule",{value:!0})});var F=u(n=>{"use strict";Object.defineProperty(n,"__esModule",{value:!0});n.PROJECT_ELEMENT_KINDS=void 0;n.PROJECT_ELEMENT_KINDS=["api","web","mobile","desktop","worker","database","integration"]});var k=u(V=>{"use strict";Object.defineProperty(V,"__esModule",{value:!0})});var w=u(G=>{"use strict";Object.defineProperty(G,"__esModule",{value:!0})});var H=u(K=>{"use strict";Object.defineProperty(K,"__esModule",{value:!0})});var W=u(Q=>{"use strict";Object.defineProperty(Q,"__esModule",{value:!0})});var Z=u(_=>{"use strict";Object.defineProperty(_,"__esModule",{value:!0});_.TAG_COLORS=void 0;_.TAG_COLORS=["brand","info","ok","warn","cyan"]});var $=u(c=>{"use strict";Object.defineProperty(c,"__esModule",{value:!0});c.LLM_PROVIDER_KINDS=void 0;c.LLM_PROVIDER_KINDS=["deepseek","claude","gemini","glm"]});var X=u(z=>{"use strict";Object.defineProperty(z,"__esModule",{value:!0})});var ee=u(o=>{"use strict";Object.defineProperty(o,"__esModule",{value:!0});o.AEGIS_CLOUD_COST_PER_DEPLOY_USD=o.PLANS=void 0;o.planById=x;o.formatTokens=re;o.aegisCloudBudget=J;o.aegisCloudCapacity=ue;o.PLANS=[{id:"starter",name:"Starter",tagline:"Construye tu primera app y prueba el flujo completo.",priceMonthly:29,tokens:15e5,overagePer1M:28,aegisCloudBudgetUsd:5,features:["1,5M tokens al mes","Proyectos ilimitados","Generaci\xF3n + auditor\xEDa de seguridad","Despliegue a Grid Cloud","Soporte por correo"]},{id:"builder",name:"Builder",tagline:"Para uso regular y varios proyectos en marcha.",priceMonthly:89,tokens:5e6,overagePer1M:22,aegisCloudBudgetUsd:20,featured:!0,features:["5M tokens al mes","Todo lo de Starter","Pipelines CI/CD y entornos","Modelos premium (Opus 4.8)","Soporte prioritario"]},{id:"scale",name:"Scale",tagline:"Equipos y cargas de producci\xF3n.",priceMonthly:249,tokens:14e6,overagePer1M:18,aegisCloudBudgetUsd:60,features:["14M tokens al mes","Todo lo de Builder","Roles y miembros de equipo","Overage m\xE1s barato","Soporte con SLA"]},{id:"enterprise",name:"Enterprise",tagline:"Volumen, gobernanza y despliegue dedicado.",priceMonthly:null,tokens:null,overagePer1M:null,aegisCloudBudgetUsd:null,features:["Tokens por volumen","SSO / SAML y auditor\xEDa","Despliegue dedicado / on-prem","Facturaci\xF3n anual","Soporte dedicado"]}];function x(e){return o.PLANS.find(i=>i.id===e)??o.PLANS[0]}function re(e){if(e===null)return"Volumen";if(e>=1e6){let i=e/1e6;return`${i%1===0?i:i.toFixed(1).replace(".",",")}M`}return e>=1e3?`${Math.round(e/1e3)}K`:String(e)}function J(e){return x(e).aegisCloudBudgetUsd}o.AEGIS_CLOUD_COST_PER_DEPLOY_USD=4;function ue(e){let i=J(e);return i===null?null:Math.floor(i/o.AEGIS_CLOUD_COST_PER_DEPLOY_USD)}});var ie=u(r=>{"use strict";var te=r&&r.__createBinding||(Object.create?function(e,i,s,d){d===void 0&&(d=s);var l=Object.getOwnPropertyDescriptor(i,s);(!l||("get"in l?!i.__esModule:l.writable||l.configurable))&&(l={enumerable:!0,get:function(){return i[s]}}),Object.defineProperty(e,d,l)}:function(e,i,s,d){d===void 0&&(d=s),e[d]=i[s]}),t=r&&r.__exportStar||function(e,i){for(var s in e)s!=="default"&&!Object.prototype.hasOwnProperty.call(i,s)&&te(i,e,s)};Object.defineProperty(r,"__esModule",{value:!0});t(E(),r);t(f(),r);t(M(),r);t(y(),r);t(g(),r);t(v(),r);t(A(),r);t(b(),r);t(T(),r);t(m(),r);t(R(),r);t(B(),r);t(Y(),r);t(F(),r);t(k(),r);t(w(),r);t(H(),r);t(W(),r);t(Z(),r);t($(),r);t(X(),r);t(ee(),r)});export{ie as a};
