import{a as e,b as i,c as o,d as m}from"./chunk-FFXRJ6QC.js";import"./chunk-TJA3KIFT.js";import"./chunk-5WGRSUVA.js";import"./chunk-KX452INR.js";import"./chunk-35XQ4LA4.js";import"./chunk-RSYYWCFT.js";import"./chunk-AXDRLRJM.js";import"./chunk-QDZMYZBI.js";import"./chunk-A37R7TWI.js";import"./chunk-QYCUXD7R.js";import"./chunk-PRKFGJVH.js";import"./chunk-TZWSGC3H.js";import"./chunk-ZKLJWGVP.js";import"./chunk-55QKDJ5H.js";import"./chunk-2K35RNHN.js";import"./chunk-E5GXGYZM.js";import"./chunk-ZZZJFKF2.js";import{a as r}from"./chunk-YUSHYV7C.js";import"./chunk-C6Q5SG76.js";var D={parser:e,get db(){return new o(2)},renderer:i,styles:m,init:r(t=>{t.state||(t.state={}),t.state.arrowMarkerAbsolute=t.arrowMarkerAbsolute},"init")};export{D as diagram};
