import{a as o,b as e}from"./chunk-YZSUPHBX.js";import"./chunk-FJYBG3F7.js";import"./chunk-QP3MATMC.js";import"./chunk-TJA3KIFT.js";import"./chunk-5WGRSUVA.js";import"./chunk-KX452INR.js";import"./chunk-35XQ4LA4.js";import"./chunk-RSYYWCFT.js";import"./chunk-AXDRLRJM.js";import"./chunk-QDZMYZBI.js";import"./chunk-A37R7TWI.js";import"./chunk-QYCUXD7R.js";import"./chunk-PRKFGJVH.js";import"./chunk-TZWSGC3H.js";import"./chunk-ZKLJWGVP.js";import"./chunk-55QKDJ5H.js";import"./chunk-2K35RNHN.js";import"./chunk-E5GXGYZM.js";import"./chunk-ZZZJFKF2.js";import{a as r}from"./chunk-YUSHYV7C.js";import"./chunk-C6Q5SG76.js";var m=r(t=>`${o(t)}
  .swimlane.cluster rect {
    stroke: ${t.clusterBorder} !important;
  }
  [data-look="neo"].cluster rect {
    filter: none;
  }
`,"getStyles"),i=m,B=e({defaultLayout:"swimlane",styles:i});export{B as diagram};
